"""App metadata."""


__project_name__ = "cizsle"
__description__ = "Cisco ZTP Server LE"
__url__ = "https://github.com/CiscoDevNet/cizsle"
__download_url__ = "https://pypi.python.org/pypi/cizsle"
__copyright__ = "Copyright (c) 2019 Cisco and/or its affiliates."
__author__ = "Cisco and Contributors"
__author_email__ = "cizsle@cisco.com"
__version__ = "0.0a7"
