"""Cizsle server app main entry point."""


def main():
    """Cizsle CLI client main entry point."""
    print("This will run the cizsle application server client.")


if __name__ == "__main__":
    main()
