"""Zero-Touch Provisioning (ZTP) Server for Cisco Network Devices."""


from cizsle._metadata import (  # noqa: F401
    __author__,
    __author_email__,
    __copyright__,
    __description__,
    __download_url__,
    __project_name__,
    __url__,
    __version__,
)
